==> discord-moderator-1.0.1.tgz: package/src/main.js <==
const { EventEmitter } = require('events');
const mergeOptions = require('merge-options');
const { writeFile, readFile, exists } = require('fs');
const { promisify } = require('util');
const writeFileAsync = promisify(writeFile);
const existsAsync = promisify(exists);
const readFileAsync = promisify(readFile);
const Discord = require('discord.js');
const { defaultOptions } = require('./Utils');
const Case = require('./Case');

/**
 * Moderator
 */
class Moderator extends EventEmitter {
    /**
     * @param {Client} client The Discord Client
     * @param {ModeratorOptions} options The manager options
     */
    constructor(client, options) {
        super();
        if (!client) throw new Error('Client is a required option.');

        /**
         * The Discord Client
         * @type {Client}
         */
        this.client = client;

        /**
         * Whether the manager is ready
         * @type {Boolean}
         */
        this.ready = false;

        /**
         * The moderation managed by this manager
         * @type {Cases[]}
         */
        this.cases = [];

        /**
         * The manager options
         * @type {ModeratorOptions}
         */
        this.options = mergeOptions(defaultOptions, options);

        /**
         * Whether the Discord.js library version is the v12 one
         * @type {boolean}
         */
        this.v12 = this.options.DJSlib === 'v12';
        this._init();
    }

    /**
     * Ends a case. This method is automatically called when a case ends.
     * @param {string} ID The case ID
     * @returns {Promise<Case>} The case
     *
     * @example
     * moderator.end("689530053268209664");
     */
    end(ID) {
        return new Promise(async (resolve) => {
            let caseData = this.cases.find(g => g.id === ID);
            if (!caseData) {
                return console.log(`No case found with ID ${ID}!`);
            }
            let caseObj = new Case(this, caseData);
            if (caseObj.ended) {
                return console.log(`Case with ID ${caseObj.id} is already ended!`)
            }
            await caseObj.fetchAuthor();
            if (!caseObj.author) {
                return console.log(`Unable to fetch the author of the case with ID ${caseObj.id}!`);
            }
            await caseObj.fetchGuild();
            if (!caseObj.guild) {
                return console.log(`Unable to fetch the guild of the case with ID ${caseObj.id}!`);
            }
            if (caseObj.type === 'mute') {
                await caseObj.fetchUser();
                try {
                    if (this.v12) {
                        caseObj.user.roles.remove(caseObj.options.mutedRoleID);
                    } else {
                        caseObj.user.removeRole(caseObj.options.mutedRoleID);
                    }
                } catch(error) {
                    this._markAsEnded(caseObj.id);
                    return console.log(`Unable to unmute the user of the case with ID ${caseObj.id}! Error: ${error}`);
                }
            }
            if(caseObj.type == 'ban') {
                try {
                    if (this.v12) {
                        caseObj.guild.members.unban(caseObj.userID)
                    } else {
                        caseObj.guild.unban(caseObj.userID)
                    }
                } catch(error) {
                    return console.log(`Unable to unban the user of the case with ID ${caseObj.id}! Error: ${error}`);
                }
            }
            this._markAsEnded(caseObj.id);
            resolve(caseObj);
            this.emit('caseDelete', caseObj);
        }).catch(e => console.log(e));
    }

    /**
     * Mute or Temp-mute a user
     *
     * @param {GuildMember} user The user
     * @param {Options} opts The options for the case
     *
     * @returns {Promise<Case>}
     *
     * @example
     * moderator.mute(message.guild.members.cache.get(message.mentions.users.first().id), {
     *      time: 1000,
     *      // Mute will last 10 seconds
     *      reason: "bad words",
     *      // Mute reason
     *      author: message.member
     *      // Author of the mute
     * });
     */
    mute(user, opts = {}) {
        return new Promise(async (resolve, reject) => {
            if (!this.ready) {
                return console.log('The moderator is not ready yet.');
            }
            if (!user) {
                return console.log(`User is not a valid GuildMember. (val=${user})`);
            }
            if (!user.guild) {
                return console.log(`User is not a valid GuildMember. (val=${user})`);
            }
            if (!opts.author) {
                return console.log(`Opts.author is not a valid GuildMember. (val=${opts.author})`);
            }
            if (!opts.author.guild) {
                return console.log(`Opts.author is not a valid GuildMember. (val=${opts.author})`);
            }
            if(!opts.mutedRoleID) {
                return console.log(`Opts.mutedRoleID is not a valid RoleID. (val=${opts.mutedRoleID})`);
            }
            let caseObj = new Case(this, {
                id: Discord.SnowflakeUtil.generate(Date.now()),
                type: 'mute',
                date: Date.now(),
                guildID: user.guild.id,
                authorID: opts.author.id,
                userID: user.id,
                channelID: opts.channel.id,
                endAt: Math.floor(Date.now() + opts.time),
                ended: opts.time ? false : true,
                reason: opts.reason ? opts.reason : 'Причина не указана!',
                options: {
                    mutedRoleID: opts.mutedRoleID
                }
            });
            if(this.v12) {
                user.roles.add(opts.mutedRoleID, `${caseObj.reason}`);
            } else {
                user.addRole(opts.mutedRoleID, `${caseObj.reason}`);
            }
            this.cases.push(caseObj);
            await this._saveCase(caseObj);
            resolve(caseObj);
            this.emit("caseCreate", caseObj);
        }).catch(e => console.log(e));
    }

    /**
     * Un-mute a user
     *
     * @param {GuildMember} user The user
     * @param {Options} opts The options for the case
     *
     * @returns {Promise<Case>}
     *
     * @example
     * moderator.unmute(message.guild.members.cache.get(message.mentions.users.first().id), {
     *      reason: "i'm nice",
     *      // Un-mute reason
     *      author: message.member
     *      // Author of the un-mute
     * });
     */
    unmute(user, opts = {}) {
        return new Promise(async (resolve) => {
            if (!this.ready) {
                return console.log('The moderator is not ready yet.');
            }
            if (!user) {
                return console.log(`User is not a valid GuildMember. (val=${user})`);
            }
            if (!user.guild) {
                return console.log(`User is not a valid GuildMember. (val=${user})`);
            }
            if (!opts.author) {
                return console.log(`Opts.author is not a valid GuildMember. (val=${opts.author})`);
            }
            if (!opts.author.guild) {
                return console.log(`Opts.author is not a valid GuildMember. (val=${opts.author})`);
            }
            if(!opts.mutedRoleID) {
                return console.log(`Opts.mutedRoleID is not a valid RoleID. (val=${opts.mutedRoleID})`);
            }
            let caseObj = new Case(this, {
                id: Discord.SnowflakeUtil.generate(Date.now()),
                type: 'unmute',
                date: Date.now(),
                guildID: user.guild.id,
                authorID: opts.author.id,
                userID: user.id,
                endAt: 0,
                ended: true,
                reason: opts.reason ? opts.reason : 'Причина не указана!',
                options: {
                    mutedRoleID: opts.mutedRoleID
                }
            });
            if(this.v12) {
                user.roles.remove(opts.mutedRoleID, `${caseObj.reason}`);
            } else {
                user.removeRole(opts.mutedRoleID, `${caseObj.reason}`);
            }
            this.cases.push(caseObj);
            await this._saveCase(caseObj);
            resolve(caseObj);
            this.emit("caseCreate", caseObj);
        }).catch(e => console.log(e));
    }
    
    /**
     * Gets the cases from the storage file, or create it
     * @ignore
     * @private
     * @returns {Array<Cases>}
     */
    async _initStorage() {
        // Whether the storage file exists, or not
        let storageExists = await existsAsync(this.options.storage);
        // If it doesn't exists
        if (!storageExists) {
            // Create the file with an empty array
            await writeFileAsync(this.options.storage, '[]', 'utf-8');
            return [];
        } else {
            // If the file exists, read it
            let storageContent = await readFileAsync(this.options.storage);
            try {
                let cases = await JSON.parse(storageContent);
                if (Array.isArray(cases)) {
                    return cases;
                } else {
                    throw new SyntaxError('The storage file is not properly formatted.');
                }
            } catch (e) {
                if (e.message === 'Unexpected end of JSON input') {
                    throw new SyntaxError('The storage file is not properly formatted.', e);
                } else {
                    throw e;
                }
            }
        }
    }

    /**
     * Save the case to the storage file
     * @ignore
     * @private
     * @param {Case} caseObj The case to save
     */
    async _saveCase(caseObj) {
        this.cases = this.cases.filter(g => g.id !== caseObj.id);
        let caseData = {
            id: caseObj.id,
            type: caseObj.type,
            date: caseObj.date,
            guildID: caseObj.guildID,
            authorID: caseObj.authorID,
            userID: caseObj.userID,
            channelID: caseObj.channelID,
            endAt: caseObj.endAt,
            ended: caseObj.ended,
            options: caseObj.options,
        };
        this.cases.push(caseData);
        await writeFileAsync(this.options.storage, JSON.stringify(this.cases), 'utf-8');
        return;
    }

    /**
     * Mark a case as ended
     * @private
     * @ignore
     * @param {string} ID The ID of the case
     */
    async _markAsEnded(ID) {
        this.cases.find(c => c.id === ID).ended = true;
        await writeFileAsync(this.options.storage, JSON.stringify(this.cases), 'utf-8');
        return;
    }

    /**
     * Checks each case and update it if needed
     * @ignore
     * @private
     */
    _checkCase() {
        if (this.cases.length <= 0) return;
        this.cases.forEach(async caseData => {
            let caseObj = new Case(this, caseData);
            if (caseObj.ended) return;
            if (!caseObj.type) return;
            if (caseObj.remainingTime <= 0) {
                this.end(caseObj.id);
            }
            await caseObj.fetchGuild();
            if (!caseObj.guild) {
                caseObj.ended = true;
                await this._markAsEnded(caseObj.id);
                return;
            }
        });
    }

    /**
     * Inits the moderator
     * @ignore
     * @private
     */
    async _init() {
        this.cases = await this._initStorage();
        setInterval(() => {
            if (this.client.readyAt) {
                this._checkCase.call(this);
            }
        }, this.options.updateCountdownEvery);
        this.ready = true;
    }
}

/**
 * Emitted when a case ends.
 * @event Moderator#caseDelete
 * @param {Case} caseObj The case instance
 * 
 * Emitted when a case create
 * @event Moderator#caseCreate
 * @param {Case} caseObj the case instance
 * 
 * @example
 * // This can be used to add features such as a log
 * moderator.on('caseDelete', (caseObj) => {
 *      console.log(caseObj);
 * });
 * 
 * moderator.on('caseCreate', (caseObj) => {
 *      console.log(caseObj);
 * });
 */

module.exports = Moderator;

==> discord-moderator-1.0.2.tgz: package/src/main.js <==
const { EventEmitter } = require('events');
const mergeOptions = require('merge-options');
const db = require('quick.db');
const { writeFile, readFile, exists } = require('fs');
const { promisify } = require('util');
const writeFileAsync = promisify(writeFile);
const existsAsync = promisify(exists);
const readFileAsync = promisify(readFile);
const Discord = require('discord.js');
const { defaultOptions } = require('./Utils');
const Case = require('./Case');

/**
 * Moderator
 */
class Moderator extends EventEmitter {
    /**
     * @param {Client} client The Discord Client
     * @param {ModeratorOptions} options The manager options
     */
    constructor(client, options) {
        super();
        if (!client) throw new Error('Client is a required option.');

        /**
         * The Discord Client
         * @type {Client}
         */
        this.client = client;

        /**
         * Whether the manager is ready
         * @type {Boolean}
         */
        this.ready = false;

        /**
         * The moderation managed by this manager
         * @type {Cases[]}
         */
        this.cases = [];

        /**
         * The manager options
         * @type {ModeratorOptions}
         */
        this.options = mergeOptions(defaultOptions, options);

        /**
         * Whether the Discord.js library version is the v12 one
         * @type {boolean}
         */
        this.v12 = this.options.DJSlib === 'v12';
        this._init();
    }

    /**
     * Mute or Temp-mute a user
     *
     * @param {GuildMember} user The user
     * @param {Options} opts The options for the case
     *
     * @returns {Promise<Case>}
     *
     * @example
     * moderator.mute(message.guild.members.cache.get(message.mentions.users.first().id), {
     *      time: 1000,
     *      // Mute will last 10 seconds
     *      reason: "bad words",
     *      // Mute reason
     *      author: message.member
     *      // Author of the mute
     * });
     */

    guildMemberAdd(member, opts) {
        let request = db.fetch(`${this.options.muteTable}.${member.guild.id}`);
        if(request == null) {

        }else{
            var i;
            var users = [];

            for(i = 0; i < request.length; i++) {
                users.push(request[i].userID);
            }
            if(users.includes(member.id)) {
                member.roles.add(opts.mutedRoleID, `Ранее был заглушён!`);
            }
        }
    }

    /**
     * Ends a case. This method is automatically called when a case ends.
     * @param {string} ID The case ID
     * @returns {Promise<Case>} The case
     *
     * @example
     * moderator.end("689530053268209664");
     */
    end(ID) {
        return new Promise(async (resolve) => {
            let caseData = this.cases.find(g => g.id === ID);
            if (!caseData) {
                return console.log(`No case found with ID ${ID}!`);
            }
            let caseObj = new Case(this, caseData);
            if (caseObj.ended) {
                return console.log(`Case with ID ${caseObj.id} is already ended!`)
            }
            await caseObj.fetchAuthor();
            if (!caseObj.author) {
                return console.log(`Unable to fetch the author of the case with ID ${caseObj.id}!`);
            }
            await caseObj.fetchGuild();
            if (!caseObj.guild) {
                return console.log(`Unable to fetch the guild of the case with ID ${caseObj.id}!`);
            }
            if (caseObj.type === 'mute') {
                await caseObj.fetchUser();
                try {
                    if (this.v12) {
                        let request = db.fetch(`${this.options.muteTable}.${caseObj.guildID}`);
                        if(request == null) {
                            caseObj.user.roles.remove(caseObj.options.mutedRoleID);
                        }else{
                            var i;
				            var users = [];

				            for(i = 0; i < request.length; i++) {
					            users.push(request[i].userID);
                            }
                            if(users.includes(caseObj.userID)) {
                                caseObj.user.roles.remove(caseObj.options.mutedRoleID, `${caseObj.reason}`);
                                let newArray = request.filter(a => a.userID !== `${caseObj.userID}`);
                                db.set(`${this.options.muteTable}.${caseObj.guildID}`, newArray);

                                if(this.options.muteMessageType == 'message') {
                                    let guild = this.client.guilds.cache.get(caseObj.guildID);
                                    let channel = guild.channels.cache.get(caseObj.channelID);
                                    channel.send(`<@${caseObj.userID}> разглушён! Причина: **Время мута вышло**`);
                                }else if(this.options.muteMessageType == 'embed') {
                                    if(!this.options.muteEmbedColor) {
                                        let guild = this.client.guilds.cache.get(caseObj.guildID);
                                        let channel = guild.channels.cache.get(caseObj.channelID);
                                        channel.send(new Discord.MessageEmbed().setColor('RANDOM').setDescription(`<@${caseObj.userID}> разглушён! Причина: **Время мута вышло**`));
                                    }else{
                                        let guild = this.client.guilds.cache.get(caseObj.guildID);
                                        let channel = guild.channels.cache.get(caseObj.channelID);
                                        channel.send(new Discord.MessageEmbed().setColor(this.options.muteEmbedColor).setDescription(`<@${caseObj.userID}> разглушён! Причина: **Время мута вышло**`));
                                    }
                                }
                            }
                        }
                    } else {
                        let request = db.fetch(`${this.options.muteTable}.${caseObj.guildID}`);
                        if(request == null) {
                            caseObj.user.removeRole(caseObj.options.mutedRoleID);
                        }else{
                            var i;
				            var users = [];

				            for(i = 0; i < request.length; i++) {
					            users.push(request[i].userID);
                            }
                            if(users.includes(caseObj.userID)) {
                                caseObj.user.removeRole(caseObj.options.mutedRoleID);
                                let newArray = request.filter(a => a.userID !== `${caseObj.userID}`);
					            db.set(`${this.options.muteTable}.${caseObj.guildID}`, newArray);
                            }
                        }
                    }
                } catch(error) {
                    this._markAsEnded(caseObj.id);
                    return console.log(`Unable to unmute the user of the case with ID ${caseObj.id}! Error: ${error}`);
                }
            }
            this._markAsEnded(caseObj.id);
            resolve(caseObj);
            this.emit('caseDelete', caseObj);
        }).catch(e => console.log(e));
    }

    /**
     * Mute or Temp-mute a user
     *
     * @param {GuildMember} user The user
     * @param {Options} opts The options for the case
     *
     * @returns {Promise<Case>}
     *
     * @example
     * moderator.mute(message.guild.members.cache.get(message.mentions.users.first().id), {
     *      time: 1000,
     *      // Mute will last 10 seconds
     *      reason: "bad words",
     *      // Mute reason
     *      author: message.member
     *      // Author of the mute
     * });
     */
    mute(user, opts = {}) {
        return new Promise(async (resolve) => {
            if (!this.ready) {
                return console.log('The moderator is not ready yet.');
            }
            if (!user) {
                return console.log(`User is not a valid GuildMember. (val=${user})`);
            }
            if (!user.guild) {
                return console.log(`User is not a valid GuildMember. (val=${user})`);
            }
            if (!opts.author) {
                return console.log(`Opts.author is not a valid GuildMember. (val=${opts.author})`);
            }
            if (!opts.author.guild) {
                return console.log(`Opts.author is not a valid GuildMember. (val=${opts.author})`);
            }
            if(!opts.mutedRoleID) {
                return console.log(`Opts.mutedRoleID is not a valid RoleID. (val=${opts.mutedRoleID})`);
            }
            let caseObj = new Case(this, {
                id: Discord.SnowflakeUtil.generate(Date.now()),
                type: 'mute',
                date: Date.now(),
                guildID: user.guild.id,
                authorID: opts.author.id,
                userID: user.id,
                channelID: opts.channel.id,
                endAt: Math.floor(Date.now() + opts.time),
                ended: opts.time ? false : true,
                reason: opts.reason ? opts.reason : 'Причина не указана!',
                options: {
                    mutedRoleID: opts.mutedRoleID
                }
            });
            if(this.v12) {
                let request = db.fetch(`${this.options.muteTable}.${caseObj.guildID}`);
                if(request == null) {
                    db.set(`${this.options.muteTable}.${caseObj.guildID}`, [{ 'userID': caseObj.userID }]);
                    user.roles.add(opts.mutedRoleID, `${caseObj.reason}`);
                }else{
                    db.push(`${this.options.muteTable}.${caseObj.guildID}`, { 'userID': caseObj.userID });
                    user.roles.add(opts.mutedRoleID, `${caseObj.reason}`);
                }
            } else {
                let request = db.fetch(`${this.options.muteTable}.${caseObj.guildID}`);
                if(request == null) {
                    db.set(`${this.options.muteTable}.${caseObj.guildID}`, [{ 'userID': caseObj.userID }]);
                    user.addRole(opts.mutedRoleID, `${caseObj.reason}`);
                }else{
                    db.push(`${this.options.muteTable}.${caseObj.guildID}`, { 'userID': caseObj.userID });
                    user.addRole(opts.mutedRoleID, `${caseObj.reason}`);
                }
            }
            this.cases.push(caseObj);
            await this._saveCase(caseObj);
            resolve(caseObj);
            this.emit("caseCreate", caseObj);
        }).catch(e => console.log(e));
    }

    /**
     * Un-mute a user
     *
     * @param {GuildMember} user The user
     * @param {Options} opts The options for the case
     *
     * @returns {Promise<Case>}
     *
     * @example
     * moderator.unmute(message.guild.members.cache.get(message.mentions.users.first().id), {
     *      reason: "i'm nice",
     *      // Un-mute reason
     *      author: message.member
     *      // Author of the un-mute
     * });
     */
    unmute(user, opts = {}) {
        return new Promise(async (resolve) => {
            if (!this.ready) {
                return console.log('The moderator is not ready yet.');
            }
            if (!user) {
                return console.log(`User is not a valid GuildMember. (val=${user})`);
            }
            if (!user.guild) {
                return console.log(`User is not a valid GuildMember. (val=${user})`);
            }
            if (!opts.author) {
                return console.log(`Opts.author is not a valid GuildMember. (val=${opts.author})`);
            }
            if (!opts.author.guild) {
                return console.log(`Opts.author is not a valid GuildMember. (val=${opts.author})`);
            }
            if(!opts.mutedRoleID) {
                return console.log(`Opts.mutedRoleID is not a valid RoleID. (val=${opts.mutedRoleID})`);
            }
            let caseObj = new Case(this, {
                id: Discord.SnowflakeUtil.generate(Date.now()),
                type: 'unmute',
                date: Date.now(),
                guildID: user.guild.id,
                authorID: opts.author.id,
                userID: user.id,
                endAt: 0,
                ended: true,
                reason: opts.reason ? opts.reason : 'Причина не указана!',
                options: {
                    mutedRoleID: opts.mutedRoleID
                }
            });
            if(this.v12) {
                let request = db.fetch(`${this.options.muteTable}.${caseObj.guildID}`);
                if(request == null) {
                    user.roles.remove(opts.mutedRoleID, `${caseObj.reason}`);
                }else{
                    var i;
				    var users = [];

				    for(i = 0; i < request.length; i++) {
					    users.push(request[i].userID);
                    }
                    if(users.includes(caseObj.userID)) {
                        user.roles.remove(opts.mutedRoleID, `${caseObj.reason}`);
                        let newArray = request.filter(a => a.userID !== `${caseObj.userID}`);
					    db.set(`${this.options.muteTable}.${caseObj.guildID}`, newArray);
                    }
                }
            } else {
                let request = db.fetch(`${this.options.muteTable}.${caseObj.guildID}`);
                if(request == null) {
                    user.removeRole(opts.mutedRoleID, `${caseObj.reason}`);
                }else{
                    var i;
				    var users = [];

				    for(i = 0; i < request.length; i++) {
					    users.push(request[i].userID);
                    }
                    if(users.includes(caseObj.userID)) {
                        user.removeRole(opts.mutedRoleID, `${caseObj.reason}`);
                        let newArray = request.filter(a => a.userID !== `${caseObj.userID}`);
					    db.set(`${this.options.muteTable}.${caseObj.guildID}`, newArray);
                    }
                }
            }
            this.cases.push(caseObj);
            await this._saveCase(caseObj);
            resolve(caseObj);
            this.emit("caseCreate", caseObj);
        }).catch(e => console.log(e));
    }
    
    /**
     * Gets the cases from the storage file, or create it
     * @ignore
     * @private
     * @returns {Array<Cases>}
     */
    async _initStorage() {
        // Whether the storage file exists, or not
        let storageExists = await existsAsync(this.options.storage);
        // If it doesn't exists
        if (!storageExists) {
            // Create the file with an empty array
            await writeFileAsync(this.options.storage, '[]', 'utf-8');
            return [];
        } else {
            // If the file exists, read it
            let storageContent = await readFileAsync(this.options.storage);
            try {
                let cases = await JSON.parse(storageContent);
                if (Array.isArray(cases)) {
                    return cases;
                } else {
                    throw new SyntaxError('The storage file is not properly formatted.');
                }
            } catch (e) {
                if (e.message === 'Unexpected end of JSON input') {
                    throw new SyntaxError('The storage file is not properly formatted.', e);
                } else {
                    throw e;
                }
            }
        }
    }

    /**
     * Save the case to the storage file
     * @ignore
     * @private
     * @param {Case} caseObj The case to save
     */
    async _saveCase(caseObj) {
        this.cases = this.cases.filter(g => g.id !== caseObj.id);
        let caseData = {
            id: caseObj.id,
            type: caseObj.type,
            date: caseObj.date,
            guildID: caseObj.guildID,
            authorID: caseObj.authorID,
            userID: caseObj.userID,
            channelID: caseObj.channelID,
            endAt: caseObj.endAt,
            ended: caseObj.ended,
            options: caseObj.options,
        };
        this.cases.push(caseData);
        await writeFileAsync(this.options.storage, JSON.stringify(this.cases), 'utf-8');
        return;
    }

    /**
     * Mark a case as ended
     * @private
     * @ignore
     * @param {string} ID The ID of the case
     */
    async _markAsEnded(ID) {
        this.cases.find(c => c.id === ID).ended = true;
        await writeFileAsync(this.options.storage, JSON.stringify(this.cases), 'utf-8');
        return;
    }

    /**
     * Checks each case and update it if needed
     * @ignore
     * @private
     */
    _checkCase() {
        if (this.cases.length <= 0) return;
        this.cases.forEach(async caseData => {
            let caseObj = new Case(this, caseData);
            if (caseObj.ended) return;
            if (!caseObj.type) return;
            if (caseObj.remainingTime <= 0) {
                this.end(caseObj.id);
            }
            await caseObj.fetchGuild();
            if (!caseObj.guild) {
                caseObj.ended = true;
                await this._markAsEnded(caseObj.id);
                return;
            }
        });
    }

    /**
     * Inits the moderator
     * @ignore
     * @private
     */
    async _init() {
        this.cases = await this._initStorage();
        setInterval(() => {
            if (this.client.readyAt) {
                this._checkCase.call(this);
            }
        }, this.options.updateCountdownEvery);
        this.ready = true;
    }

    async newMemberMuted(client, member) {
        return new Promise(async () => {
            let caseData = this.cases.find(g => g.userID === member.id);
            if (!caseData) {
                return console.log(`No case found with ID ${ID}!`);
            }
            let caseObj = new Case(this, caseData);
            if(caseObj.guildID !== member.guild.id) {
                let data = this.cases.find(a => a.guildID === member.guild.id);
                let request = db.fetch(`${this.options.muteTable}.${member.guild.id}`);
                if(request == null) {

                }else{
                    var i;
				    var users = [];

				    for(i = 0; i < request.length; i++) {
					    users.push(request[i].userID);
                    }
                    if(users.includes(data.userID)) {
                        caseObj.user.roles.add(caseObj.options.mutedRoleID, `Был обнаружен мут`);
                    }else{

                    }
                }
            }
        })
    }
}

/**
 * Emitted when a case ends.
 * @event Moderator#caseDelete
 * @param {Case} caseObj The case instance
 * 
 * Emitted when a case create
 * @event Moderator#caseCreate
 * @param {Case} caseObj the case instance
 * 
 * @example
 * // This can be used to add features such as a log
 * moderator.on('caseDelete', (caseObj) => {
 *      console.log(caseObj);
 * });
 * 
 * moderator.on('caseCreate', (caseObj) => {
 *      console.log(caseObj);
 * });
 */

module.exports = Moderator;
